This is an automated email from the ASF dual-hosted git repository.

andytaylor pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/activemq-artemis-console.git


The following commit(s) were added to refs/heads/main by this push:
     new e4ad157  ARTEMIS-5631 - Update hawtio to v4.5
e4ad157 is described below

commit e4ad157fd50652603af13ae3712e9b7b8a054888
Author: GChuf <[email protected]>
AuthorDate: Wed Sep 3 15:10:39 2025 +0200

    ARTEMIS-5631 - Update hawtio to v4.5
---
 README.md                                          |  4 +--
 .../artemis-extension/app/public/index.html        |  2 +-
 .../artemis-extension/app/webpack.config.cjs       | 34 +++++++++++-----------
 pom.xml                                            |  2 +-
 4 files changed, 20 insertions(+), 22 deletions(-)

diff --git a/README.md b/README.md
index 384c244..179def2 100644
--- a/README.md
+++ b/README.md
@@ -74,9 +74,7 @@ cd artemis-console-extension/artemis-extension/app
 npm run start
 ```
 
-Now you should be able to preview the plugins under development at 
<http://localhost:8080/hawtio/>. However, since it still
+Now you should be able to preview the plugins under development at 
<http://localhost:8080/console/>. However, since it still
 hasn't been connected to a backend JVM, you can then connect to a running 
Artemis instance using the connect tab using for
 instance http://localhost:8161/console/jolokia.
 You can now edit the artemis console web application and see changes loaded 
live.
-
-The URL uses `/hawtio` base path due to a [Hawtio 
bug](https://github.com/hawtio/hawtio/issues/3885).
\ No newline at end of file
diff --git a/artemis-console-extension/artemis-extension/app/public/index.html 
b/artemis-console-extension/artemis-extension/app/public/index.html
index b158795..a120322 100644
--- a/artemis-console-extension/artemis-extension/app/public/index.html
+++ b/artemis-console-extension/artemis-extension/app/public/index.html
@@ -19,7 +19,7 @@
 <html lang="en">
   <head>
     <meta charset="utf-8" />
-    <base href="/hawtio/" />
+    <base href="/console/" />
     <meta name="description" content="ActiveMQ Artemis Management Console" />
 
     <!-- Hawtio branding styles and favicon placeholders -->
diff --git a/pom.xml b/pom.xml
index 8f064fa..912b47c 100644
--- a/pom.xml
+++ b/pom.xml
@@ -44,7 +44,7 @@
         <maven.compiler.source>17</maven.compiler.source>
         <maven.compiler.target>17</maven.compiler.target>
         <maven.compiler.release>17</maven.compiler.release>
-        <hawtio.version>4.4.1</hawtio.version>
+        <hawtio.version>4.5.0</hawtio.version>
         <jakarta.servlet-api.version>5.0.0</jakarta.servlet-api.version>
         <slf4j.version>2.0.17</slf4j.version>
         <log4j.version>2.24.3</log4j.version>


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]
For further information, visit: https://activemq.apache.org/contact


Reply via email to
diff --git a/artemis-console-extension/artemis-extension/app/webpack.config.cjs 
b/artemis-console-extension/artemis-extension/app/webpack.config.cjs
index bae8c0f..37881ad 100644
--- a/artemis-console-extension/artemis-extension/app/webpack.config.cjs
+++ b/artemis-console-extension/artemis-extension/app/webpack.config.cjs
@@ -78,7 +78,7 @@ module.exports = (webpackEnv, args) => {
       //   can be used to reconstruct the HTML if necessary
       new WebpackManifestPlugin({
         fileName: 'asset-manifest.json',
-        publicPath: '/hawtio',
+        publicPath: '/console',
         generate: (seed, files, entrypoints) => {
           const manifestFiles = files.reduce((manifest, file) => {
             manifest[file.name] = file.path;
@@ -316,14 +316,14 @@ module.exports = (webpackEnv, args) => {
       static: [
         {
           directory: path.resolve(__dirname, "build"),
-          publicPath: "/hawtio",
+          publicPath: "/console",
         }
       ],
       historyApiFallback: {
-        index: "/hawtio/"
+        index: "/console/"
       },
       devMiddleware: {
-        publicPath: "/hawtio",
+        publicPath: "/console",
         mimeTypes: {
           mjs: "application/javascript"
         },
@@ -333,13 +333,13 @@ module.exports = (webpackEnv, args) => {
           // Enabling branding in dev mode
           devServer.app.use((req, _, next) => {
             if (req.url.startsWith('/artemis-extension')) {
-              req.url = req.url.replace(/\/artemis-plugin(.*)/, '/hawtio$1')
+              req.url = req.url.replace(/\/artemis-plugin(.*)/, '/console$1')
             }
             next()
           })
-          // Redirect / or /hawtio to /hawtio/
-          devServer.app.get('/', (_, res) => res.redirect('/hawtio/'))
-          devServer.app.get('/hawtio$', (_, res) => res.redirect('/hawtio/'))
+          // Redirect / or /console to /console/
+          devServer.app.get('/', (_, res) => res.redirect('/console/'))
+          devServer.app.get('/console$', (_, res) => res.redirect('/console/'))
 
           const username = 'developer'
           const proxyEnabled = true
@@ -348,30 +348,30 @@ module.exports = (webpackEnv, args) => {
 
           // Hawtio backend API mock
           let login = true
-          devServer.app.get('/hawtio/user', (_, res) => {
+          devServer.app.get('/console/user', (_, res) => {
             login ? res.send(`"${username}"`) : res.sendStatus(403)
           })
-          devServer.app.post('/hawtio/auth/login', (_, res) => {
+          devServer.app.post('/console/auth/login', (_, res) => {
             login = true
             res.send(String(login))
           })
-          devServer.app.get('/hawtio/auth/logout', (_, res) => {
+          devServer.app.get('/console/auth/logout', (_, res) => {
             login = false
-            res.redirect('/hawtio/login')
+            res.redirect('/console/login')
           })
-          devServer.app.get('/hawtio/auth/config/session-timeout', (_, res) => 
{
+          devServer.app.get('/console/auth/config/session-timeout', (_, res) 
=> {
             res.type('application/json')
             res.send('{}')
           })
-          devServer.app.get('/hawtio/proxy/enabled', (_, res) => 
res.send(String(proxyEnabled)))
-          devServer.app.get('/hawtio/plugin', (_, res) => 
res.send(JSON.stringify(plugin)))
+          devServer.app.get('/console/proxy/enabled', (_, res) => 
res.send(String(proxyEnabled)))
+          devServer.app.get('/console/plugin', (_, res) => 
res.send(JSON.stringify(plugin)))
 
           // hawtconfig.json mock
-          devServer.app.get('/hawtio/hawtconfig.json', (_, res) => 
res.send(JSON.stringify(hawtconfig)))
+          devServer.app.get('/console/hawtconfig.json', (_, res) => 
res.send(JSON.stringify(hawtconfig)))
 
           middlewares.push({
             name: 'hawtio-backend',
-            path: '/hawtio/proxy',
+            path: '/console/proxy',
             middleware: hawtioBackend({
               // Uncomment it if you want to see debug log for Hawtio backend
               logLevel: 'debug',